@@ -35,19 +35,17 @@
 (require 'seq)
 (require 'jira-fmt)
 (require 'jira-api)
-(require 'jira-edit)
-(require 'org) ; `org-id-uuid'
 
 ;; these blocks contain the content property
 (defconst jira-doc--top-level-blocks
   '("blockquote" "bulletList" "codeBlock" "expand" "heading" "mediaGroup"
     "mediaSingle" "orderedList" "panel" "paragraph" "rule" "table"
-    "multiBodiedExtension" "taskList"))
+    "multiBodiedExtension"))
 
 ;; these blocks contain the content property
 (defconst jira-doc--child-blocks
   '("listItem" "media" "nestedExpand" "tableCell" "tableHeader"
-    "tableRow" "extensionFrame" "taskItem"))
+    "tableRow" "extensionFrame"))
 
 (defconst jira-doc--inline-blocks
   '("date" "emoji" "hardBreak" "inlineCard" "mention" "status"
@@ -90,15 +88,6 @@
     (message "The timestamp is %s" timestamp)
     (jira-fmt-date s t)))
 
-(defun jira-doc--format-task-item (block)
-  "Format BLOCK, a taskItem node, as a string."
-  (let* ((attrs (alist-get 'attrs block))
-         (state (alist-get 'state attrs)))
-    (concat (jira-fmt-task-item (string= state "DONE"))
-            " "
-            (string-join (mapcar #'jira-doc--format-inline-block
-                                 (alist-get 'content block))))))
-
 (defun jira-doc--marks (block)
   "Return a list of mark attributes from BLOCK."
   (let ((m* '()))
@@ -139,8 +128,6 @@
              (jira-fmt-emoji text)))
           ((string= type "date")
            (jira-doc--format-date block))
-          ((string= type "taskItem")
-           (jira-doc--format-task-item block))
           (text (let ((marks (jira-doc--marks block)))
                   (jira-fmt-with-marks text marks))))))
 
@@ -153,8 +140,7 @@
   "A thunk returning a prefix for list item nodes.")
 
 (defun jira-doc--format-boxed-text (text prefix)
-  "Format TEXT in an ASCII box with line wrapping.
-PREFIX is used for the box border."
+  "Format TEXT in an ASCII box with line wrapping."
   (let* ((fill-column 80)
          (lines (with-temp-buffer
                   (insert text) (fill-region (point-min) (point-max))
@@ -181,8 +167,7 @@ PREFIX is used for the box border."
      (string-join media "\n"))))
 
 (defun jira-doc--format-media (block)
-  "Format an individual media node to a string.
-BLOCK is the media node to format."
+  "Format an individual media node to a string."
   (let* ((attrs (alist-get 'attrs block))
          (type (alist-get 'type attrs))
          (id (alist-get 'id attrs))
@@ -197,15 +182,7 @@ BLOCK is the media node to format."
                (if (string= "" collection) "" (concat collection ":"))
                (if (and alt (not (string= "" alt))) alt id))))))
 
-(defun jira-doc--format-task-list (block)
-  "Format a taskList node to a string."
-  (let ((children (alist-get 'content block)))
-    (string-join (mapcar #'jira-doc--format-inline-block
-                         children)
-                 "\n")))
-
 (defun jira-doc--format-table-row (block)
-  "Format a table row BLOCK to a string."
   (mapcar #'jira-doc--format-content-block
           (alist-get 'content block)))
 
@@ -283,8 +260,6 @@ BLOCK is the media node to format."
 			   ((string= ptype "note") "✏️")
 			   (t ""))))
 	(jira-doc--format-boxed-text content prefix)))
-     ((string= type "taskList")
-      (jira-doc--format-task-list block))
      (t content))))
 
 (defun jira-doc--format-list-block (block)
@@ -392,19 +367,19 @@ which do not match are returned as-is."
 (defun jira-doc--build-marked-text (text)
   "Split TEXT into a list of ADF text nodes with marks."
   (let* ((mark-regexp (concat "\\_<\\("
-                              (string-join (mapcar (lambda (d)
+                              (string-join (mapcar #'(lambda (d)
                                                        (let ((delim (regexp-quote (car d))))
-                                                         (concat delim "[^" delim "]+?" delim)))
+                                                         (concat delim ".+?" delim)))
                                                    jira-doc--marks-delimiters)
                                            "\\|")
                               "\\)\\_>"))
          (areas (jira-doc--split (list text)
                                  mark-regexp
-                                 (lambda (s)
+                                 #'(lambda (s)
                                      (pcase (jira-doc--collect-marks s)
                                        (`(,body ,marks)
                                         (jira-doc--build-text body marks)))))))
-    (mapcar (lambda (s)
+    (mapcar #'(lambda (s)
                 (if (stringp s)
                     (jira-doc--build-text s)
                   s))
@@ -434,8 +409,7 @@ NAME should be a username defined in `jira-users'."
        (("id" . ,account-id))))))
 
 (defun jira-doc--build-link (contents)
-  "Make an ADF link node.
-CONTENTS is the link text and URL."
+  "Make an ADF link node."
   (let* ((has-title (string-search "|" contents))
          (title (if has-title
                     (substring contents 0 has-title)
@@ -450,28 +424,23 @@ CONTENTS is the link text and URL."
                                ("title" . ,title))))))))
 
 (defun jira-doc--build-code (contents)
-  "Make an ADF text node marked as code.
-CONTENTS is the code text to mark."
+  "Make an ADF text node marked as code."
   (jira-doc--build-text contents
                         `((("type" . "code")))))
 
 (defun jira-doc--build-emoji (name)
-  "Make an ADF emoji node.
-NAME is the emoji name."
+  "Make an ADF emoji node."
   `(("type" . "emoji")
     ("attrs" .
      (("shortName" . ,name)))))
 
 (defun jira-doc--build-code-block (body)
-  "Make an ADF codeBlock node.
-BODY is the code block content."
+  "Make an ADF codeBlock node."
   `(("type" . "codeBlock")
     ("content"
      ,(jira-doc--build-text (string-trim body)))))
 
 (defun jira-doc--build-blockquote (quoted-text)
-  "Make an ADF blockquote node.
-QUOTED-TEXT is the text to quote."
   `(("type" . "blockquote")
     ("content"
      (("type" . "paragraph")
@@ -479,8 +448,7 @@ QUOTED-TEXT is the text to quote."
        ,@(jira-doc-build-inline-blocks quoted-text))))))
 
 (defun jira-doc--build-heading (heading-text)
-  "Make an ADF heading node.
-HEADING-TEXT is the heading text."
+  "Make an ADF heading node."
   (let ((level (aref heading-text 0))
         (content (substring heading-text 3))) ; skip "[1-6]. "
     `(("type" . "heading")
@@ -490,26 +458,22 @@ HEADING-TEXT is the heading text."
        ,@(jira-doc-build-inline-blocks content)))))
 
 (defun jira-doc--build-rule ()
-  "Make an ADF rule node (horizontal rule)."
   `(("type" . "rule")))
 
 (defun jira-doc--build-list-item (&rest children)
-  "Make an ADF listItem node.
-CHILDREN are the list item contents."
+  "Make an ADF listItem node."
   `(("type" . "listItem")
     ("content" . ,children)))
 
 (defun jira-doc--build-list (items ordered-p)
-  "Make an ADF bulletList or orderedList node.
-ITEMS are the list items and ORDERED-P determines if it's ordered."
+  "Make an ADF bulletList or orderedList node."
   `(("type" . ,(if ordered-p
                    "orderedList"
                  "bulletList"))
     ("content" . ,items)))
 
 (defun jira-doc--build-table-row (text separator)
-  "Make an ADF tableRow node and child nodes out of TEXT.
-SEPARATOR determines if it's a header or cell row."
+  "Make an ADF tableRow node and child nodes out of TEXT."
   (let ((cell-type (if (string= separator "||")
                        "tableHeader"
                      "tableCell"))
@@ -520,7 +484,7 @@ SEPARATOR determines if it's a header or cell row."
     ;; inside table cells. So instead we just scan for inline blocks,
     ;; whick can all be written inside table markup.
     `(("type" . "tableRow")
-      ("content" . ,(mapcar (lambda (text)
+      ("content" . ,(mapcar #'(lambda (text)
                                 `(("type" . ,cell-type)
                                   ("content" .
                                    ((("type" . "paragraph")
@@ -531,37 +495,16 @@ SEPARATOR determines if it's a header or cell row."
                             (take (- (length cells) 2)
                                   (cdr cells)))))))
 
-(defun jira-doc--build-task-item (state children)
-  "Make an ADF taskItem node."
-  `(("type" . "taskItem")
-    ("content" ,@children)
-    ("attrs" .
-     (("localId" . ,(org-id-uuid))
-      ("state" . ,(if state
-                      "DONE"
-                    "TODO"))))))
-
-(defun jira-doc--build-task-list (children)
-  "Make an ADF taskList node."
-  `(("type" . "taskList")
-    ("attrs" .
-     (("localId" . ,(org-id-uuid))))
-    ("content" ,@children)))
-
 (defun jira-doc--build-table (rows)
-  "Make an ADF table node.
-ROWS are the table rows."
+  "Make an ADF table node."
   `(("type" . "table")
     ("content" . ,rows)))
 
 (defun jira-doc-build-inline-blocks (text)
-  "Parse inline block nodes out of TEXT and convert everything to ADF nodes.
-Links and code are actually kinds of marks, but their ADF structure is not
-like other marks, so it's easier to pretend they're blocks."
+  "Parse inline block nodes out of TEXT and convert everything to ADF nodes."
   (let ((blocks (jira-doc--split (list text)
                                  jira-regexp-mention
                                  #'jira-doc--build-mention)))
-    (setq blocks (jira-doc-build-task-lists blocks))
     ;; links and code are actually kinds of marks, but their ADF
     ;; structure is not like other marks, so it's easier to pretend
     ;; they're blocks.
@@ -584,7 +527,7 @@ like other marks, so it's easier to pretend they're blocks."
   ;; mark list items: depth, ordered?, text
   (let* ((b* (jira-doc--split (list block)
                               jira-regexp-list-item
-                              (lambda (prefix text)
+                              #'(lambda (prefix text)
                                   `(list-item ,(length prefix)
                                               ,(eq (aref prefix (1- (length prefix)))
                                                    ?#)
@@ -594,7 +537,7 @@ like other marks, so it's easier to pretend they're blocks."
          (stack '())
          (cur '())
          (ordered-p nil)
-         (finish-list (lambda ()
+         (finish-list #'(lambda ()
                           "Create the list node for CUR and put it where it belongs."
                           (when cur
                             (let ((l (jira-doc--build-list (reverse cur)
@@ -607,7 +550,7 @@ like other marks, so it's easier to pretend they're blocks."
                                     (setf (alist-get "content" parent nil nil #'equal)
                                           (append (alist-get "content" parent nil nil #'equal)
                                                   (list l))))))))))
-         (pop-lists (lambda (n)
+         (pop-lists #'(lambda (n)
                         "Finish N lists on STACK."
                         (dotimes (_ n)
                           (funcall finish-list)
@@ -691,45 +634,12 @@ like other marks, so it's easier to pretend they're blocks."
             res))
     (reverse res)))
 
-(defun jira-doc-build-task-lists (blocks)
-  "Collect task items out of BLCOKS and group them into taskList nodes."
-  (let ((res '())
-        (cur-list nil))
-    (dolist (b
-             (jira-doc--split blocks
-                              jira-regexp-task-item
-                              #'(lambda (marker text)
-                                  (jira-doc--build-task-item (string-match-p (rx "[" (not space) "]")
-                                                                             marker)
-                                                             (jira-doc-build-inline-blocks
-                                                              (string-trim text))))))
-      (pcase b
-        ((map ("type" "taskItem"))
-         (push b cur-list))
-        ("\n")
-        (_
-         (when cur-list
-           (push (jira-doc--build-task-list (reverse cur-list))
-                 res)
-           (setq cur-list nil))
-         (push b res))))
-    (when cur-list
-      (push (jira-doc--build-task-list (reverse cur-list))
-            res))
-    (reverse res)))
-
-(defun jira-doc--split-paragraphs (blocks)
-  (jira-doc--split blocks
-                   "\n\\([ 	]*\n\\)+"
-                   #'string-trim))
-
 (defun jira-doc-build-toplevel-blocks (text)
   "Parse toplevel blocks out of TEXT and convert to ADF nodes."
   (let ((blocks
 	 (thread-first
-	   (list text)
-	   (jira-doc--split jira-regexp-code-block  #'jira-doc--build-code-block)
-           jira-doc--split-paragraphs
+	   text
+	   (jira-doc--split jira-regexp-code-block #'jira-doc--build-code-block)
 	   (jira-doc--split jira-regexp-blockquote  #'jira-doc--build-blockquote)
 	   (jira-doc--split jira-regexp-heading     #'jira-doc--build-heading)
 	   (jira-doc--split jira-regexp-hr          #'jira-doc--build-rule)
@@ -744,9 +654,13 @@ like other marks, so it's easier to pretend they're blocks."
 
 (defun jira-doc-build-adf (text)
   "Build a Jira document (ADF) from TEXT."
-  `(("type" . "doc") ("version" . 1)
-    ("content" .
-     ,(jira-doc-build-toplevel-blocks text))))
+  (let* ((paras (mapcar #'string-trim
+                        (split-string (or text "")
+                                      "\n\\([ 	]*\n\\)+"
+                                      t))))
+    `(("type" . "doc") ("version" . 1)
+      ("content" .
+       ,(jira-doc-build-toplevel-blocks paras)))))
 
 ;;; Building v2 texts.
 (defun jira-doc-build-v2 (text)
