@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025 Pablo González Carrizo
 
 ;; Author: Pablo González Carrizo <unmonoqueteclea@gmail.com>
-;; Package-Version: 2.21.0
-;; Package-Revision: b578426e7f4d
+;; Package-Version: 20251011.1501
+;; Package-Revision: 762c0e3bd9f4
 ;; Created: 2025-02-16
 ;; URL: https://github.com/unmonoqueteclea/jira.el
 ;; Package-Requires: ((emacs "29.1") (request "0.3.0") (tablist "1.0") (transient "0.8.3") (magit-section "4.2.0"))
@@ -33,10 +33,9 @@
 ;;; Code:
 
 (require 'jira-issues)
-(require 'jira-export)
 (require 'jira-tempo)
 
-(defconst jira-version "jira.el v2.21.0" "Jira.el package version.")
+(defconst jira-version "jira.el v2.10.2" "jira.el package version.")
 
 (provide 'jira)
 
